@@ -204,6 +204,7 @@ cal_fill_event_list_ui(CalHomePlugin* desktop_plugin)
       GtkWidget* summary_label = gtk_label_new(NULL);
 
       gtk_label_set_markup(GTK_LABEL(summary_label), summary);
+
       g_free(summary);
       
       hildon_helper_set_logical_font(summary_label,
@@ -263,7 +264,9 @@ cal_date_on_today(CComponent* component,
   }
   else
   {
+
     time_get_local_ex(t, &time);
+
   }
   return time.tm_year == desktop_plugin->date_today.tm_year &&
     time.tm_mon == desktop_plugin->date_today.tm_mon &&
@@ -373,7 +376,9 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 	escaped_markedup = g_markup_printf_escaped("<span foreground=\"#ff0000\"><b>%s</b></span>", summary.c_str());
       }
       else
+      {
 	escaped_markedup = g_markup_printf_escaped("%s", summary.c_str());
+      }
 
       summary = string(escaped_markedup);
       g_free(escaped_markedup);
@@ -504,8 +509,8 @@ calendar_getComponents(int calendarId,
   CMulticalendar *mc = CMulticalendar::MCInstance();
   int time_diff = time_get_time_diff(iStDate, mc->getSystemTimeZone().c_str(), "UTC");
 
-  iNewStDate = iStDate + time_diff;
-  iNewEndDate = iEndDate + time_diff;
+  iNewStDate = iStDate - time_diff;
+  iNewEndDate = iEndDate - time_diff;
 
   if (pDb == 0) 
   {
@@ -515,16 +520,17 @@ calendar_getComponents(int calendarId,
   char *sqlQuery = 
     sqlite3_mprintf(
 		    "select * from %s where "
-		    "%s = %d  AND  %s = %d AND (%s + %s) < %d AND (%s + %s) > %d AND (%s != %d AND %s != %d) "
+		    "%s = %d  AND  %s = %d AND (%s - %s) < %d AND (%s - %s) > %d AND (%s != %d AND %s != %d) "
 		    "union select * from %s where "
-		    "%s = %d AND  %s = %d  AND (%s = 2  OR allday = 1) AND (%s + %s)>= %d AND (%s + %s)< %d AND (%s != %d AND %s != %d) " 
+		    "%s = %d AND  %s = %d  AND (%s = 2  OR allday = 1) AND (%s - %s)>= %d AND (%s - %s)< %d AND (%s != %d AND %s != %d) " 
 		    "union select * from %s where "
 		    "%s = %d AND %s = %d  AND allday = 0 AND (%s = %d OR %s = %d) AND (%d < %s OR %d = %s) "
 		    "union select * from %s where "
 		    "%s = %d AND %s = %d  AND allday = 1 AND (%s = %d OR %s = %d) AND (%d < (%s + %s) OR %d = %s) "
 		    "LIMIT %d OFFSET %d",
 		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId,
-		    ENTRY_FIELD_TYPE, type,ENTRY_FIELD_DTSTART, ENTRY_FIELD_TZOFFSET, iNewEndDate,ENTRY_FIELD_DTEND, ENTRY_FIELD_TZOFFSET, iNewStDate,
+		    ENTRY_FIELD_TYPE, type,ENTRY_FIELD_DTSTART, ENTRY_FIELD_TZOFFSET, iNewEndDate,ENTRY_FIELD_DTEND, 
+		    ENTRY_FIELD_TZOFFSET, iNewStDate,
 		    ENTRY_FIELD_FLAGS, HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM,
 		    
 		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId, ENTRY_FIELD_TYPE, type, ENTRY_FIELD_TYPE,
@@ -757,7 +763,6 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
     for(int k = 0;k<calendars_components.size();++k)
     {
       CComponent* component = calendars_components[k];
-
       vector<time_t> instance_times =
 	component->getInstanceTimes(last_start_date, 
 				    end_time);
